@@ -47,6 +47,8 @@ def compare_object(x, y, context):
         return compare_simple(x, y, context)
     x_attrs = _extract_attrs(x)
     y_attrs = _extract_attrs(y)
+    if x_attrs is None or y_attrs is None:
+        return compare_simple(x, y, context)
     if x_attrs != y_attrs:
         return _compare_mapping(x_attrs, y_attrs, context, x,
                                 'attributes ', '.%s')
@@ -219,6 +221,8 @@ def compare_set(x, y, context):
     """
     x_not_y = x - y
     y_not_x = y - x
+    if not (y_not_x or x_not_y):
+        return
     lines = ['%s not as expected:' % x.__class__.__name__, '']
     x_label = context.x_label or 'first'
     y_label = context.y_label or 'second'
